# InvTaskInfo

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**args** | [**dict(str, AdvanceArg)**](AdvanceArg.md) |  | [optional] 
**comment** | **str** |  | [optional] 
**conditions** | [**list[TaskCondition]**](TaskCondition.md) |  | [optional] 
**in_task_id** | **str** |  | [optional] 
**input** | **str** |  | [optional] 
**inv_id** | **str** |  | [optional] 
**loop_args** | [**dict(str, AdvanceArg)**](AdvanceArg.md) |  | [optional] 
**loop_condition** | [**list[ArgFilter]**](ArgFilter.md) |  | [optional] 
**version** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


